==> ionic-roles-component-1.0.0.tgz: package/index.js <==
import { Component, Input, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @param {?} userId
 * @param {?} rules
 * @return {?}
 */
function pode(userId, rules) {
    var /** @type {?} */ user = userList.filter(function (u) { return u._id === userId_x; })[0];
    var /** @type {?} */ permissoes = [];
    Object.keys(rolesGroup).forEach(function (r) {
        if (user.roles.some(function (_r) { return _r == r; })) {
            rolesGroup[r].forEach(function (_r) {
                if (permissoes.every(function (p) { return _r != p; }))
                    permissoes.push(_r);
            });
        }
        
    });
    return permissoes.some(function (p) { return rules.indexOf(p) >= 0; });
}
var userId_x = "userMarcelloId";
var rolesGroup = {
    gerente: [
        "gerente",
        "recepcao"
    ],
    administrador: [
        "gerente",
        "financeiro",
        "administrador",
        "recepcao",
    ],
    recepcao: [
        "recepcao",
    ],
    financeiro: [
        "financeiro"
    ]
};
var userList = [
    {
        _id: 'userGislainyId',
        email: 'gislainycrisostomo@gmail.com',
        roles: ["gerente"]
    },
    {
        _id: 'userJoseId',
        email: 'joseneto.design@gmail.com',
        roles: ["administrador"]
    },
    {
        _id: 'userMarcelloId',
        email: 'marcellovcs@gmail.com',
        roles: ["recepcao"]
    },
    {
        _id: 'userRamonId',
        email: 'ramonhenrique@gmail.com',
        roles: ["gerente", "financeiro"]
    },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated class for the PodeComponent component.
 *
 * See https://angular.io/api/core/Component for more info on Angular
 * Components.
 */
var PodeComponent = /** @class */ (function () {
    function PodeComponent() {
        // debugger
        // this.text = text;
        // this.rules = "administrador";
        // console.log('Hello PodeComponent Component');
        this._text = 'Hello World';
    }
    /**
     * @return {?}
     */
    PodeComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () { };
    Object.defineProperty(PodeComponent.prototype, "rules", {
        get: /**
         * @return {?}
         */
        function () {
            return this.rules;
        },
        set: /**
         * @param {?} rules
         * @return {?}
         */
        function (rules) {
            this._rules = rules;
            this._rules_arr = this._rules.split(', ');
        },
        enumerable: true,
        configurable: true
    });
    // pode_fn() {
    //   debugger
    //   return pode('teste', this._rules_arr);
    // }
    /**
     * @return {?}
     */
    PodeComponent.prototype.pode_fn = /**
     * @return {?}
     */
    function () {
        return pode('teste', this._rules_arr);
    };
    PodeComponent.decorators = [
        { type: Component, args: [{
                    selector: 'pode',
                    templateUrl: 'pode.html'
                },] },
    ];
    /** @nocollapse */
    PodeComponent.ctorParameters = function () { return []; };
    PodeComponent.propDecorators = {
        "title": [{ type: Input },],
        "rules": [{ type: Input, args: ['rules',] },],
    };
    return PodeComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var components = [PodeComponent];
var ComponentsModule = /** @class */ (function () {
    function ComponentsModule() {
    }
    ComponentsModule.decorators = [
        { type: NgModule, args: [{
                    declarations: components,
                    imports: components,
                    exports: components,
                    entryComponents: components
                },] },
    ];
    return ComponentsModule;
}());

export { ComponentsModule };

==> ionic-roles-component-1.0.1.tgz: package/index.js <==
import { Component, Input, NgModule } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @param {?} userId
 * @param {?} rules
 * @return {?}
 */
function pode(userId, rules) {
    var /** @type {?} */ user = userList.filter(function (u) { return u._id === userId_x; })[0];
    var /** @type {?} */ permissoes = [];
    Object.keys(rolesGroup).forEach(function (r) {
        if (user.roles.some(function (_r) { return _r == r; })) {
            rolesGroup[r].forEach(function (_r) {
                if (permissoes.every(function (p) { return _r != p; }))
                    permissoes.push(_r);
            });
        }
        
    });
    return permissoes.some(function (p) { return rules.indexOf(p) >= 0; });
}
var userId_x = "userMarcelloId";
var rolesGroup = {
    gerente: [
        "gerente",
        "recepcao"
    ],
    administrador: [
        "gerente",
        "financeiro",
        "administrador",
        "recepcao",
    ],
    recepcao: [
        "recepcao",
    ],
    financeiro: [
        "financeiro"
    ]
};
var userList = [
    {
        _id: 'userGislainyId',
        email: 'gislainycrisostomo@gmail.com',
        roles: ["gerente"]
    },
    {
        _id: 'userJoseId',
        email: 'joseneto.design@gmail.com',
        roles: ["administrador"]
    },
    {
        _id: 'userMarcelloId',
        email: 'marcellovcs@gmail.com',
        roles: ["recepcao"]
    },
    {
        _id: 'userRamonId',
        email: 'ramonhenrique@gmail.com',
        roles: ["gerente", "financeiro"]
    },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated class for the PodeComponent component.
 *
 * See https://angular.io/api/core/Component for more info on Angular
 * Components.
 */
var PodeComponent = /** @class */ (function () {
    function PodeComponent() {
        // debugger
        // this.text = text;
        // this.rules = "administrador";
        // console.log('Hello PodeComponent Component');
        this._text = 'Hello World';
    }
    /**
     * @return {?}
     */
    PodeComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () { };
    Object.defineProperty(PodeComponent.prototype, "rules", {
        get: /**
         * @return {?}
         */
        function () {
            return this.rules;
        },
        set: /**
         * @param {?} rules
         * @return {?}
         */
        function (rules) {
            this._rules = rules;
            this._rules_arr = this._rules.split(', ');
        },
        enumerable: true,
        configurable: true
    });
    // pode_fn() {
    //   debugger
    //   return pode('teste', this._rules_arr);
    // }
    /**
     * @return {?}
     */
    PodeComponent.prototype.pode_fn = /**
     * @return {?}
     */
    function () {
        return pode('teste', this._rules_arr);
    };
    PodeComponent.decorators = [
        { type: Component, args: [{
                    selector: 'pode',
                    templateUrl: 'pode.html'
                },] },
    ];
    /** @nocollapse */
    PodeComponent.ctorParameters = function () { return []; };
    PodeComponent.propDecorators = {
        "title": [{ type: Input },],
        "rules": [{ type: Input, args: ['rules',] },],
    };
    return PodeComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
var components = [PodeComponent];
var RolesComponentModules = /** @class */ (function () {
    function RolesComponentModules() {
    }
    RolesComponentModules.decorators = [
        { type: NgModule, args: [{
                    declarations: components,
                    imports: components,
                    exports: components,
                    entryComponents: components
                },] },
    ];
    return RolesComponentModules;
}());

export { RolesComponentModules };
